@@ -1,14 +1,13 @@
 import warnings
 
 import numpy as np
-from pycce.io.base import DFTCoordinates, fortran_value, find_first_index, set_isotopes
 from pycce.bath.array import BathArray, transform
 from pycce.constants import MHZ_TO_KHZ, BOHR_TO_ANGSTROM, EFG_CONVERSION
+from pycce.io.base import DFTCoordinates, fortran_value, find_first_index, set_isotopes
 
 qe_coord_types = ['crystal', 'bohr', 'angstrom', 'alat']
 
 
-
 def read_qe(pwfile, hyperfine=None, efg=None, s=1, pwtype=None, types=None, isotopes=None,
             center=None, center_type=None, rotation_matrix=None, rm_style='col', find_isotopes=True):
     r"""
@@ -124,7 +123,8 @@ class PWCoordinates(DFTCoordinates):
             None
 
         """
-        lines = open(filename).readlines()
+        with open(filename) as f:
+            lines = f.readlines()
         alat_index = find_first_index('lattice parameter (alat)', lines)
 
         self.alat = float(lines[alat_index].split()[-2]) * BOHR_TO_ANGSTROM
@@ -199,7 +199,9 @@ class PWCoordinates(DFTCoordinates):
             to_angstrom (bool): True if automatically convert the units of ``cell`` and ``coordinates`` to Angstrom.
 
         """
-        input_string = open(filename).read()
+        with open(filename) as f:
+            input_string = f.read()
+
         namelists = read_qe_namelists(input_string.lower())
         lines = input_string.splitlines()
 
@@ -244,7 +246,6 @@ class PWCoordinates(DFTCoordinates):
         coords = []
 
         for i in range(index + 1, index + 1 + namelists['system']['nat']):
-
             row_split = lines[i].split()
             names.append(row_split[0])
             coords.append([float(x) for x in row_split[1:]])
@@ -445,6 +446,7 @@ def celldms_from_abc(ibrav, abc_list):
 
     return celldm
 
+
 def read_gipaw_tensors(lines, keyword=None, start=None, conversion=1):
     """
     Helper function to read GIPAW tensors from the list of lines.
@@ -502,7 +504,8 @@ def read_hyperfine(filename, spin=1):
     """
     conversion = MHZ_TO_KHZ / (2 * spin)
 
-    lines = open(filename).readlines()
+    with open(filename) as f:
+        lines = f.readlines()
 
     dipol_keyword = 'total dipolar (symmetrized)'
     contact_keyword = 'Fermi contact in MHz'
@@ -533,7 +536,9 @@ def read_efg(filename):
 
     """
     efg_kw = 'total EFG (symmetrized)'
-    lines = open(filename).readlines()
+    with open(filename) as f:
+        lines = f.readlines()
+
     tensors = read_gipaw_tensors(lines, keyword=efg_kw, conversion=EFG_CONVERSION)
 
     return np.asarray(tensors)
